ChainEvent

Enum ChainEvent 

pub enum ChainEvent<B: BlockT> {
    NewBlock {
        hash: B::Hash,
    },
    NewBestBlock {
        hash: B::Hash,
        tree_route: Option<Arc<TreeRoute<B>>>,
    },
    Finalized {
        hash: B::Hash,
        tree_route: Arc<[B::Hash]>,
    },
}
Events that the transaction pool listens for.

Variants



NewBlock

A new block (which is not the new best block) was added to the chain.

It allows the transaction pool to maintain views for all forks, not only the best chain. Pools that only care about the best chain may ignore this event.

Fields

hash: B::Hash

Hash of the block.



NewBestBlock

New best block have been added to the chain.

Fields

hash: B::Hash

Hash of the block.

tree_route: Option<Arc<TreeRoute<B>>>

Tree route from old best to new best parent that was calculated on import.

If None, no re-org happened on import.



Finalized

An existing block has been finalized.

Fields

hash: B::Hash

Hash of just finalized block.

tree_route: Arc<[B::Hash]>

Path from old finalized to new finalized parent.

Implementations

Source

impl<B: BlockT> ChainEvent<B>

pub fn hash(&self) -> B::Hash

Returns the block hash associated to the event.

pub fn is_finalized(&self) -> bool

Is self == Self::Finalized?