Enum sc_transaction_pool_api::TransactionStatus [−][src]
pub enum TransactionStatus<Hash, BlockHash> {
Future,
Ready,
Broadcast(Vec<String>),
InBlock(BlockHash),
Retracted(BlockHash),
FinalityTimeout(BlockHash),
Finalized(BlockHash),
Usurped(Hash),
Dropped,
Invalid,
}Expand description
Possible transaction status events.
This events are being emitted by TransactionPool watchers,
which are also exposed over RPC.
The status events can be grouped based on their kinds as:
- Entering/Moving within the pool:
-
Future-Ready - Inside
Readyqueue: -Broadcast - Leaving the pool:
-
InBlock-Invalid-Usurped-Dropped- Re-entering the pool:
Retracted
- Block finalized:
FinalizedFinalityTimeout
- Re-entering the pool:
The events will always be received in the order described above, however
there might be cases where transactions alternate between Future and Ready
pool, and are Broadcast in the meantime.
There is also only single event causing the transaction to leave the pool. I.e. only one of the listed ones should be triggered.
Note that there are conditions that may cause transactions to reappear in the pool.
- Due to possible forks, the transaction that ends up being in included in one block, may later re-enter the pool or be marked as invalid.
- Transaction
Droppedat one point, may later re-enter the pool if some other transactions are removed. Invalidtransaction may become valid at some point in the future. (Note that runtimes are encouraged to useUnknownValidityto inform the pool about such case).Retractedtransactions might be included in some next block.
The stream is considered finished only when either Finalized or FinalityTimeout
event is triggered. You are however free to unsubscribe from notifications at any point.
The first one will be emitted when the block, in which transaction was included gets
finalized. The FinalityTimeout event will be emitted when the block did not reach finality
within 512 blocks. This either indicates that finality is not available for your chain,
or that finality gadget is lagging behind. If you choose to wait for finality longer, you can
re-subscribe for a particular transaction hash manually again.
Variants
Transaction is part of the future queue.
Transaction is part of the ready queue.
The transaction has been broadcast to the given peers.
Transaction has been included in block with given hash.
The block this transaction was included in has been retracted.
Maximum number of finality watchers has been reached, old watchers are being removed.
Transaction has been finalized by a finality-gadget, e.g GRANDPA
Transaction has been replaced in the pool, by another transaction that provides the same tags. (e.g. same (sender, nonce)).
Transaction has been dropped from the pool because of the limit.
Transaction is no longer valid in the current state.