pub enum ChainEvent<B: BlockT> {
NewBlock {
hash: B::Hash,
},
NewBestBlock {
hash: B::Hash,
tree_route: Option<Arc<TreeRoute<B>>>,
},
Finalized {
hash: B::Hash,
tree_route: Arc<[B::Hash]>,
},
}Expand description
Events that the transaction pool listens for.
Variants
NewBlock
A new block (which is not the new best block) was added to the chain.
It allows the transaction pool to maintain views for all forks, not only the best chain. Pools that only care about the best chain may ignore this event.
NewBestBlock
New best block have been added to the chain.
Fields
Finalized
An existing block has been finalized.
Implementations
Sourceimpl<B: BlockT> ChainEvent<B>
impl<B: BlockT> ChainEvent<B>